@@ -1,5 +1,5 @@
-from bclib.context.source_context import SourceContext
-from bclib.context.source_member_context import SourceMemberContext
+from bclib.context.client_source_context import ClientSourceContext
+from bclib.context.client_source_member_context import ClientSourceMemberContext
 from bclib.context.context import Context
 from bclib.context.restful_context import RESTfulContext
 from bclib.context.web_context import WebContext
@@ -9,3 +9,5 @@ from bclib.context.socket_context import SocketContext
 from bclib.context.merge_type import MergeType
 from bclib.context.server_source_context import ServerSourceContext
 from bclib.context.server_source_member_context import ServerSourceMemberContext
+from bclib.context.source_context import SourceContext
+from bclib.context.source_member_context import SourceMemberContext
