@@ -15,6 +15,16 @@ if TYPE_CHECKING:
 class IDispatcher(ABC):
     """Dispatcher base class with core functionality for manage cache and background process"""
 
+    @property
+    @abstractmethod
+    def log_error(self) -> bool:
+        pass
+
+    @property
+    @abstractmethod
+    def log_request(self) -> bool:
+        pass
+
     @property
     @abstractmethod
     def event_loop(self) -> asyncio.AbstractEventLoop:
