@@ -1,10 +1,8 @@
-from bclib.listener.endpoint import EndPoint
+from bclib.listener.endpoint import Endpoint
 from bclib.listener.socket_listener import SocketListener
 from bclib.listener.rabbit_bus_listener import RabbitBusListener
-from bclib.listener.duplex_socket_listener import DuplexSocketListener
 from bclib.listener.message import Message
 from bclib.listener.message_type import MessageType
-
 from bclib.listener.http_listener.http_listener import HttpListener
 from bclib.listener.http_listener.http_base_data_name import HttpBaseDataName
 from bclib.listener.http_listener.http_base_data_type import HttpBaseDataType
