@@ -10,7 +10,7 @@ class InList(Predicate):
         super().__init__(expression)
         self.__items = [*items]
 
-    def check(self, context: Context) -> bool:
+    async def check_async(self, context: Context) -> bool:
         try:
             value = eval(self.exprossion, {}, {"context": context})
             return value in self.__items
