@@ -9,7 +9,7 @@ class LessThanEqual (Predicate):
         super().__init__(expression)
         self.__value = value
 
-    def check(self, context: Context) -> bool:
+    async def check_async(self, context: Context) -> bool:
         try:
             value = eval(self.exprossion, {}, {"context": context})
             return self.__value >= value
