@@ -10,7 +10,7 @@ class NotEqual (Predicate):
         super().__init__(expression)
         self.__value = value
 
-    def check(self, context: Context) -> bool:
+    async def check_async(self, context: Context) -> bool:
         try:
             value = eval(self.exprossion, {}, {"context": context})
             return self.__value != value
