@@ -2,10 +2,14 @@ class DictEx(dict):
     """Extended version of dict class for dot.notation access to attributes"""
 
     def __init__(self, *args, **kwargs):
+        super().__init__()
         for arg in args:
             if isinstance(arg, dict):
                 DictEx.fill_from_dic(self, arg)
 
+    def has(self, key: str) -> bool:
+        return key in self
+
     @classmethod
     def create(cls, data: dict):
         ret_val = DictEx()
